@@ -17,11 +17,11 @@ Test::Mock::Redis - use in place of Redis for unit testing
 
 =head1 VERSION
 
-Version 0.13
+Version 0.15
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.15';
 
 =head1 SYNOPSIS
 
@@ -68,6 +68,10 @@ handles by default. If you need to change that, do
 
     use Test::Mock::Redis num_databases => 21;
 
+or at run-time
+
+    Test::Mock::Redis::change_num_databases(21);
+
 =cut
 
 my $NUM_DBS = 16;
@@ -76,10 +80,14 @@ sub import {
     my ($class, %args) = @_;
 
     if ($args{num_databases}){
-        $NUM_DBS = $args{num_databases};
+        change_num_databases($args{num_databases});
     }
 }
 
+sub change_num_databases {
+    $NUM_DBS = shift;
+}
+
 
 sub _new_db {
     tie my %hash, 'Test::Mock::Redis::PossiblyVolatile';
@@ -312,11 +320,14 @@ sub msetnx {
 }
 
 sub del {
-    my ( $self, $key ) = @_;
+    my ( $self, @keys ) = @_;
 
-    my $ret = $self->exists($key);
+    my $ret = 0;
 
-    delete $self->_stash->{$key};
+    for my $key (@keys) {
+        $ret++ if $self->exists($key);
+        delete $self->_stash->{$key};
+    }
 
     return $ret;
 }
@@ -503,6 +514,11 @@ sub rpop {
 sub select {
     my ( $self, $index ) = @_;
 
+    my $max_index = $#{ $self->{_stash} };
+    if ($index > $max_index ){
+        die "You called select($index), but max allowed is $max_index unless you configure more databases"; 
+    }
+
     $self->{_db_index} = $index;
     return 'OK';
 }
@@ -1129,10 +1145,14 @@ The following people have contributed to I<Test::Mock::Redis>:
 
 =over
 
+=item * Ian Burrell
+
 =item * Karen Etheridge
 
 =item * Kevin Goess
 
+=item * Neil Bowers
+
 =back
 
 =head1 LICENSE AND COPYRIGHT
@@ -1267,6 +1287,22 @@ sub discard {
     return 'OK';
 }
 
+sub watch {
+    my ($self) = shift;
+
+    confess '[watch] ERR wrong number of arguments for \'watch\' command' unless @_;
+
+    return 'OK';
+}
+
+sub unwatch {
+    my ($self) = shift;
+
+    confess '[error] ERR wrong number of arguments for \'unwatch\' command' if @_;
+
+    return 'OK';
+}
+
 # now that we've defined all our subs, we need to wrap them all in logic that
 # can check if we are in the middle of a MULTI, and if so, queue up the
 # commands for later replaying.
@@ -1278,6 +1314,7 @@ my %no_transaction_wrap_methods = (
     discard => 1,
     quit => 1,
     import => 1,
+    change_num_databases => 1,
 );
 
 my @transaction_wrapped_methods =
